@@ -4,6 +4,13 @@ import copy
 from datetime import datetime
 
 
+def deserialize_json(method, _json):
+    try:
+        return json.loads(_json)
+    except Exception as e:
+        get_error(method, e)
+
+
 def get_error(method, *args, **kwargs):
     error_string = ""
 
